<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:StUF="http://www.egem.nl/StUF/StUF0301"
                xmlns:BG="http://www.egem.nl/StUF/sector/bg/0310"
                xmlns:exslt="http://exslt.org/common"
                extension-element-prefixes="exslt">

    <xsl:template name="Generate_BG_vesLa01">
        <xsl:param name="vestigingsNummer"/>
        <xsl:param name="datumAanvang"/>
        <xsl:param name="datumEinde"/>
        <xsl:param name="registratieTijdstip"/>
        <xsl:param name="typeringVestiging"/>
        <xsl:param name="residenceAdr"/>
        <xsl:param name="foreignAdr"/>
        <xsl:param name="postalAdr"/>
        <xsl:param name="sub.telefoonnummer"/>
        <xsl:param name="sub.faxnummer"/>
        <xsl:param name="sub.emailadres"/>
        <xsl:param name="sub.url"/>
        <xsl:param name="sub.rekeningnummerBankGiro"/>
        <xsl:param name="activiteiten"/>
        <xsl:param name="handelsnaamen"/>

        <BG:vesLa01>
            <BG:stuurgegevens>
                <StUF:berichtcode>La01</StUF:berichtcode>
                <StUF:entiteittype>VES</StUF:entiteittype>
            </BG:stuurgegevens>

            <BG:parameters>
                <StUF:indicatorVervolgvraag>false</StUF:indicatorVervolgvraag>
            </BG:parameters>

            <BG:antwoord>
                <BG:object StUF:entiteittype="VES">
                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'vestigingsNummer'"/>
                        <xsl:with-param name="elementSource" select="$vestigingsNummer"/>
                    </xsl:call-template>

                    <xsl:if test="$vestigingsNummer">
                        <xsl:call-template name="addStUFElementAdHoc">
                            <xsl:with-param name="elementName" select="'authentiek'"/>
                            <xsl:with-param name="elementValue" select="'J'"/>
                            <xsl:with-param name="isMetaElement" select="true()"/>
                        </xsl:call-template>
                    </xsl:if>

                    <xsl:call-template name="BG_addHandelsnaamen">
                        <xsl:with-param name="handelsnaamen" select="$handelsnaamen"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'datumAanvang'"/>
                        <xsl:with-param name="elementSource" select="$datumAanvang"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'datumEinde'"/>
                        <xsl:with-param name="elementSource" select="$datumEinde"/>
                    </xsl:call-template>

                    <xsl:call-template name="BG_addActiviteiten">
                        <xsl:with-param name="activiteiten" select="$activiteiten"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'typeringVestiging'"/>
                        <xsl:with-param name="elementSource" select="$typeringVestiging"/>
                    </xsl:call-template>

                    <xsl:call-template name="BG_addResidenceAddress">
                        <xsl:with-param name="residenceAdr" select="$residenceAdr"/>
                    </xsl:call-template>

                    <xsl:if test="not($residenceAdr)">
                        <xsl:call-template name="BG_addForeignAddress">
                            <xsl:with-param name="foreignAdr" select="$foreignAdr"/>
                        </xsl:call-template>
                    </xsl:if>

                    <xsl:call-template name="BG_addPostalAddress">
                        <xsl:with-param name="postalAdr" select="$postalAdr"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'sub.telefoonnummer'"/>
                        <xsl:with-param name="elementSource" select="$sub.telefoonnummer"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'sub.faxnummer'"/>
                        <xsl:with-param name="elementSource" select="$sub.faxnummer"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'sub.emailadres'"/>
                        <xsl:with-param name="elementSource" select="$sub.emailadres"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'sub.url'"/>
                        <xsl:with-param name="abbreviateToLength" select="200"/>
                        <xsl:with-param name="elementSource" select="$sub.url"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'sub.rekeningnummerBankGiro'"/>
                        <xsl:with-param name="elementSource" select="$sub.rekeningnummerBankGiro"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElement">
                        <xsl:with-param name="elementName" select="'tijdstipRegistratie'"/>
                        <xsl:with-param name="elementNS" select="'http://www.egem.nl/StUF/StUF0301'"/>
                        <xsl:with-param name="elementSource" select="$registratieTijdstip"/>
                    </xsl:call-template>
                </BG:object>
            </BG:antwoord>
        </BG:vesLa01>
    </xsl:template>

</xsl:stylesheet>