<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:BG="http://www.egem.nl/StUF/sector/bg/0310"
                xmlns:exslt="http://exslt.org/common"
                extension-element-prefixes="exslt">

    <xsl:template name="BG_addActiviteiten">
        <xsl:param name="activiteiten"/>
        <xsl:param name="withVolgorde" select="false()"/>

        <xsl:if test="$activiteiten">
            <xsl:for-each select="exslt:node-set($activiteiten)//activiteit">
                <BG:activiteit>
                    <xsl:call-template name="addStUFElementAdHoc">
                        <xsl:with-param name="elementName" select="'code'"/>
                        <xsl:with-param name="elementValue" select="code"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElementAdHoc">
                        <xsl:with-param name="elementName" select="'omschrijving'"/>
                        <xsl:with-param name="elementValue" select="omschrijving"/>
                    </xsl:call-template>

                    <xsl:call-template name="addStUFElementAdHoc">
                        <xsl:with-param name="elementName" select="'indicatieHoofdactiviteit'"/>
                        <xsl:with-param name="elementValue" select="indicatieHoofd"/>
                    </xsl:call-template>

                    <xsl:if test="$withVolgorde=true()">
                        <xsl:call-template name="addStUFElementAdHoc">
                            <xsl:with-param name="elementName" select="'volgorde'"/>
                            <xsl:with-param name="elementValue" select="position()"/>
                        </xsl:call-template>
                    </xsl:if>
                </BG:activiteit>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>

    <xsl:template name="BG_addHandelsnaamen">
        <xsl:param name="handelsnaamen"/>

        <xsl:if test="$handelsnaamen">
            <xsl:for-each select="exslt:node-set($handelsnaamen)//handelsnaam">
                <xsl:call-template name="addStUFElementAdHoc">
                    <xsl:with-param name="elementName" select="'handelsnaam'"/>
                    <xsl:with-param name="abbreviateToLength" select="200"/>
                    <xsl:with-param name="elementValue" select="naam"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElementAdHoc">
                    <xsl:with-param name="elementName" select="'volgorde'"/>
                    <xsl:with-param name="elementValue" select="position()"/>
                </xsl:call-template>
            </xsl:for-each>
        </xsl:if>

    </xsl:template>

    <xsl:template name="BG_addResidenceAddress">
        <xsl:param name="residenceAdr"/>

        <xsl:if test="$residenceAdr">
            <BG:verblijfsadres>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'aoa.identificatie'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//aoa.identificatie"/>
                </xsl:call-template>

                <xsl:if test="exslt:node-set($residenceAdr)//aoa.identificatie">
                    <xsl:call-template name="addStUFElementAdHoc">
                        <xsl:with-param name="elementName" select="'authentiek'"/>
                        <xsl:with-param name="elementValue" select="'N'"/>
                        <xsl:with-param name="isMetaElement" select="true()"/>
                    </xsl:call-template>
                </xsl:if>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'wpl.woonplaatsNaam'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//wpl.woonplaatsNaam"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'gor.openbareRuimteNaam'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//gor.openbareRuimteNaam"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'gor.straatnaam'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//gor.straatnaam"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'aoa.postcode'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//aoa.postcode"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'aoa.huisnummer'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//aoa.huisnummer"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'aoa.huisletter'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//aoa.huisletter"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'aoa.huisnummertoevoeging'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($residenceAdr)//aoa.huisnummertoevoeging"/>
                </xsl:call-template>

            </BG:verblijfsadres>
        </xsl:if>
    </xsl:template>

    <xsl:template name="BG_addForeignAddress">
        <xsl:param name="foreignAdr"/>

        <xsl:if test="$foreignAdr">
            <BG:sub.verblijfBuitenland>
                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'lnd.landcode'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($foreignAdr)//lnd.landcode"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'lnd.landnaam'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($foreignAdr)//lnd.landnaam"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'sub.adresBuitenland1'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($foreignAdr)//sub.adresBuitenland1"/>
                    <xsl:with-param name="abbreviateToLength" select="35"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'sub.adresBuitenland2'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($foreignAdr)//sub.adresBuitenland2"/>
                    <xsl:with-param name="abbreviateToLength" select="35"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'sub.adresBuitenland3'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($foreignAdr)//sub.adresBuitenland3"/>
                    <xsl:with-param name="abbreviateToLength" select="35"/>
                </xsl:call-template>
            </BG:sub.verblijfBuitenland>
        </xsl:if>
    </xsl:template>

    <xsl:template name="BG_addPostalAddress">
        <xsl:param name="postalAdr"/>

        <xsl:if test="$postalAdr">
            <BG:sub.correspondentieAdres>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'wpl.woonplaatsNaam'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//wpl.woonplaatsNaam"/>
                </xsl:call-template>

                <xsl:call-template name="addStUFElement">
                    <xsl:with-param name="elementName" select="'postcode'"/>
                    <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//postcode"/>
                </xsl:call-template>

                <xsl:choose>
                    <xsl:when test="exslt:node-set($postalAdr)//sub.postadresNummer">
                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'sub.postadresType'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//sub.postadresType"/>
                        </xsl:call-template>

                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'sub.postadresNummer'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//sub.postadresNummer"/>
                        </xsl:call-template>
                    </xsl:when>

                    <xsl:otherwise>
                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'aoa.identificatie'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//aoa.identificatie"/>
                        </xsl:call-template>

                        <xsl:if test="exslt:node-set($postalAdr)//aoa.identificatie">
                            <xsl:call-template name="addStUFElementAdHoc">
                                <xsl:with-param name="elementName" select="'authentiek'"/>
                                <xsl:with-param name="elementValue" select="'N'"/>
                                <xsl:with-param name="isMetaElement" select="true()"/>
                            </xsl:call-template>
                        </xsl:if>

                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'gor.openbareRuimteNaam'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//gor.openbareRuimteNaam"/>
                        </xsl:call-template>

                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'gor.straatnaam'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//gor.straatnaam"/>
                        </xsl:call-template>

                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'aoa.huisnummer'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//aoa.huisnummer"/>
                        </xsl:call-template>

                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'aoa.huisletter'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//aoa.huisletter"/>
                        </xsl:call-template>

                        <xsl:call-template name="addStUFElement">
                            <xsl:with-param name="elementName" select="'aoa.huisnummertoevoeging'"/>
                            <xsl:with-param name="elementSource" select="exslt:node-set($postalAdr)//aoa.huisnummertoevoeging"/>
                        </xsl:call-template>
                    </xsl:otherwise>
                </xsl:choose>

            </BG:sub.correspondentieAdres>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>