<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:kvk="http://www.kvk.nl/StUF/sector/hr/0300">

    <xsl:template name="NHR_readActiviteiten">

        <xsl:param name="mainActivity"/>
        <xsl:param name="allActivities"/>

        <xsl:if test="$allActivities">
            <activiteiten>
                <xsl:for-each select="$allActivities">
                    <xsl:variable name="indicatieHoofdActiviteit">
                        <xsl:choose>
                            <xsl:when test="$mainActivity=.">
                                <xsl:value-of select="'J'"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="'N'"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>

                    <xsl:call-template name="NHR_readActiviteit">
                        <xsl:with-param name="_indicatieHoofdactiviteit" select="$indicatieHoofdActiviteit"/>
                    </xsl:call-template>
                </xsl:for-each>
            </activiteiten>
        </xsl:if>
    </xsl:template>

    <xsl:template name="NHR_readActiviteit">
        <xsl:param name="_indicatieHoofdactiviteit" select="'N'"/>

        <activiteit>
            <xsl:call-template name="addElement">
                <xsl:with-param name="expr" select="format-number(number(kvk:sbiCode), '000000000000000')"/>
                <xsl:with-param name="tag" select="'code'"/>
            </xsl:call-template>

            <xsl:call-template name="addElement">
                <xsl:with-param name="expr" select="kvk:omschrijving"/>
                <xsl:with-param name="tag" select="'omschrijving'"/>
            </xsl:call-template>

            <xsl:call-template name="addElement">
                <xsl:with-param name="expr" select="$_indicatieHoofdactiviteit"/>
                <xsl:with-param name="tag" select="'indicatieHoofd'"/>
            </xsl:call-template>
        </activiteit>
    </xsl:template>

    <xsl:template name="NHR_readResidenceAddress">
        <xsl:param name="adr"/>

        <xsl:if test="$adr">
            <residenceAddress>
                <aoa.identificatie>
                    <xsl:value-of select="$adr/kvk:BAGIdentificatie/kvk:identificatieAdresseerbaarObject"/>
                </aoa.identificatie>

                <wpl.woonplaatsNaam>
                    <xsl:value-of select="$adr/kvk:plaats"/>
                </wpl.woonplaatsNaam>

                <gor.openbareRuimteNaam>
                    <xsl:value-of select="$adr/kvk:straatnaam[string-length(.) &lt; 25]"/>
                </gor.openbareRuimteNaam>

                <gor.straatnaam>
                    <xsl:value-of select="$adr/kvk:straatnaam[string-length(.) &lt; 25]"/>
                </gor.straatnaam>

                <aoa.postcode>
                    <xsl:value-of select="concat($adr/kvk:postcode/kvk:cijfercombinatie, $adr/kvk:postcode/kvk:lettercombinatie)"/>
                </aoa.postcode>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="$adr/kvk:huisnummer"/>
                    <xsl:with-param name="tag" select="'aoa.huisnummer'"/>
                </xsl:call-template>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="$adr/kvk:huisletter"/>
                    <xsl:with-param name="tag" select="'aoa.huisletter'"/>
                </xsl:call-template>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="$adr/kvk:huisnummerToevoeging"/>
                    <xsl:with-param name="tag" select="'aoa.huisnummertoevoeging'"/>
                </xsl:call-template>
            </residenceAddress>
        </xsl:if>

    </xsl:template>


    <xsl:template name="NHR_readForeignAddress">
        <xsl:param name="adr"/>

        <xsl:if test="$adr">
            <foreignAddress>
                <lnd.landnaam>
                    <xsl:value-of select="$adr/kvk:land"/>
                </lnd.landnaam>

                <sub.adresBuitenland1>
                    <xsl:value-of select="$adr/kvk:straatHuisnummer"/>
                </sub.adresBuitenland1>

                <sub.adresBuitenland2>
                    <xsl:value-of select="$adr/kvk:postcodeWoonplaats"/>
                </sub.adresBuitenland2>

                <sub.adresBuitenland3>
                    <xsl:value-of select="$adr/kvk:regio"/>
                </sub.adresBuitenland3>

            </foreignAddress>
        </xsl:if>

    </xsl:template>

    <xsl:template name="NHR_readPostalAddress">
        <xsl:param name="adr"/>

        <xsl:if test="$adr">
            <postalAddress>
                <wpl.woonplaatsNaam>
                    <xsl:value-of select="$adr/kvk:plaats"/>
                </wpl.woonplaatsNaam>

                <postcode>
                    <xsl:value-of select="concat($adr/kvk:postcode/kvk:cijfercombinatie, $adr/kvk:postcode/kvk:lettercombinatie)"/>
                </postcode>

                <aoa.identificatie>
                    <xsl:value-of select="$adr/kvk:BAGIdentificatie/kvk:identificatieAdresseerbaarObject"/>
                </aoa.identificatie>

                <gor.openbareRuimteNaam>
                    <xsl:value-of select="$adr/kvk:straatnaam[string-length(.) &lt; 25]"/>
                </gor.openbareRuimteNaam>

                <gor.straatnaam>
                    <xsl:value-of select="$adr/kvk:straatnaam[string-length(.) &lt; 25]"/>
                </gor.straatnaam>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="$adr/kvk:huisnummer"/>
                    <xsl:with-param name="tag" select="'aoa.huisnummer'"/>
                </xsl:call-template>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="$adr/kvk:huisletter"/>
                    <xsl:with-param name="tag" select="'aoa.huisletter'"/>
                </xsl:call-template>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="$adr/kvk:huisnummerToevoeging"/>
                    <xsl:with-param name="tag" select="'aoa.huisnummertoevoeging'"/>
                </xsl:call-template>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="'P'"/>
                    <xsl:with-param name="tag" select="'sub.postadresType'"/>
                </xsl:call-template>

                <xsl:call-template name="addElement">
                    <xsl:with-param name="expr" select="$adr/kvk:postbusnummer"/>
                    <xsl:with-param name="tag" select="'sub.postadresNummer'"/>
                </xsl:call-template>
            </postalAddress>
        </xsl:if>
    </xsl:template>

    <xsl:template name="addElement">
        <xsl:param name="expr"/>
        <xsl:param name="tag"/>

        <xsl:if test="$expr">
            <xsl:element name="{$tag}">
                <xsl:value-of select="$expr"/>
            </xsl:element>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>