<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:kvk="http://www.kvk.nl/StUF/sector/hr/0300">

    <xsl:template match="kvk:commercieleVestiging">
        <xsl:variable name="vestigingsNummer" select="kvk:vestigingsnummer"/>
        <xsl:variable name="datumAanvang" select="kvk:datumAanvang"/>
        <xsl:variable name="datumEinde" select="kvk:datumEinde"/>
        <xsl:variable name="registratieTijdstip" select="kvk:registratieTijdstip"/>

        <xsl:variable name="sub.telefoonnummer">
            <xsl:call-template name="formatTelefoonFaxNummer">
                <xsl:with-param name="nummer" select="kvk:communicatieGegevens/kvk:nummer[kvk:soort = 'Telefoon'][1]"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="sub.faxnummer">
            <xsl:call-template name="formatTelefoonFaxNummer">
                <xsl:with-param name="nummer" select="kvk:communicatieGegevens/kvk:nummer[kvk:soort = 'Fax'][1]"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="sub.emailadres" select="kvk:communicatieGegevens/kvk:emailAdres[1]"/>
        <xsl:variable name="sub.url" select="kvk:communicatieGegevens/kvk:domeinNaam[1]"/>

        <xsl:variable name="activiteiten">
            <xsl:call-template name="NHR_readActiviteiten">
                <xsl:with-param name="mainActivity" select="kvk:activiteiten/kvk:hoofdSbiActiviteit[kvk:hoofdactiviteit='Ja'][1]"/>
                <xsl:with-param name="allActivities" select="kvk:activiteiten/kvk:hoofdSbiActiviteit|kvk:activiteiten/kvk:sbiActiviteit"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="handelsnaamen">
            <xsl:apply-templates select="kvk:handeltOnder/kvk:gerelateerde[1]"/>
        </xsl:variable>

        <xsl:variable name="residenceAdr">
            <xsl:call-template name="NHR_readResidenceAddress">
                <xsl:with-param name="adr" select="kvk:bezoekLocatie/kvk:binnenlandsAdres[not(kvk:postbusnummer)]"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="foreignAdr">
            <xsl:call-template name="NHR_readForeignAddress">
                <xsl:with-param name="adr" select="(kvk:bezoekLocatie/kvk:buitenlandsAdres|kvk:postLocatie/kvk:buitenlandsAdres)[1]"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:variable name="postalAdr">
            <xsl:call-template name="NHR_readPostalAddress">
                <xsl:with-param name="adr" select="(kvk:postLocatie/kvk:binnenlandsAdres|kvk:bezoekLocatie/kvk:binnenlandsAdres[kvk:postbusnummer])[1]"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:call-template name="Generate_BG_vesLa01">
            <xsl:with-param name="vestigingsNummer" select="$vestigingsNummer"/>
            <xsl:with-param name="datumAanvang" select="$datumAanvang"/>
            <xsl:with-param name="datumEinde" select="$datumEinde"/>
            <xsl:with-param name="registratieTijdstip" select="$registratieTijdstip"/>
            <xsl:with-param name="sub.telefoonnummer" select="$sub.telefoonnummer"/>
            <xsl:with-param name="sub.faxnummer" select="$sub.faxnummer"/>
            <xsl:with-param name="sub.emailadres" select="$sub.emailadres"/>
            <xsl:with-param name="sub.url" select="$sub.url"/>
            <xsl:with-param name="activiteiten" select="$activiteiten"/>
            <xsl:with-param name="residenceAdr" select="$residenceAdr"/>
            <xsl:with-param name="foreignAdr" select="$foreignAdr"/>
            <xsl:with-param name="postalAdr" select="$postalAdr"/>
            <xsl:with-param name="handelsnaamen" select="$handelsnaamen"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="formatTelefoonFaxNummer">
        <xsl:param name="nummer"/>

        <xsl:if test="$nummer">
            <elementContent>
                <elementValue>
                    <xsl:value-of select="concat($nummer//kvk:toegangscode, $nummer//kvk:nummer)"/>
                </elementValue>
            </elementContent>
        </xsl:if>
    </xsl:template>

    <xsl:template match="kvk:handeltOnder/kvk:gerelateerde[1]">
        <handelsnaamen>
            <xsl:for-each select="handeltOnderEntry">
                <handelsnaam>
                    <naam>
                        <xsl:value-of select="kvk:handelsnaam"/>
                    </naam>
                </handelsnaam>
            </xsl:for-each>
        </handelsnaamen>
    </xsl:template>

</xsl:stylesheet>