<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:kvk="http://www.kvk.nl/StUF/sector/hr/0300"
                xmlns:StUF="http://www.egem.nl/StUF/StUF0301"
                xmlns:BG="http://www.egem.nl/StUF/sector/bg/0310">

    <xsl:template match="kvk:commercieleVestiging">
        <BG:vesLa01>
            <BG:stuurgegevens>
                <StUF:berichtcode>La01</StUF:berichtcode>
                <StUF:entiteittype>VES</StUF:entiteittype>
            </BG:stuurgegevens>
            <BG:parameters>
                <StUF:indicatorVervolgvraag>false</StUF:indicatorVervolgvraag>
            </BG:parameters>
            <BG:antwoord>
                <xsl:call-template name="fillInCVS"/>
            </BG:antwoord>
        </BG:vesLa01>
    </xsl:template>

    <xsl:template name="fillInCVS">
        <BG:object StUF:entiteittype="VES">
            <xsl:apply-templates select="kvk:vestigingsnummer"/>
            <xsl:apply-templates select="kvk:handeltOnder/kvk:gerelateerde"/>
            <xsl:apply-templates select="kvk:datumAanvang"/>
            <xsl:apply-templates select="kvk:datumEinde"/>
            <xsl:apply-templates select="kvk:activiteiten"/>

            <xsl:apply-templates select="kvk:bezoekLocatie/kvk:binnenlandsAdres[not(kvk:bezoekLocatie/kvk:binnenlandsAdres/kvk:postbusnummer)]"/>
            <xsl:apply-templates select="kvk:bezoekLocatie/kvk:binnenlandsAdres/kvk:postbusnummer[not(kvk:postLocatie)]"/>
            <xsl:apply-templates select="kvk:bezoekLocatie/kvk:buitenlandsAdres"/>
            <xsl:apply-templates select="kvk:bezoekLocatie/kvk:binnenlandsAdresVanaf"/>

            <xsl:apply-templates select="kvk:postLocatie/kvk:binnenlandsAdres"/>
            <xsl:apply-templates select="kvk:postLocatie/kvk:buitenlandsAdres[not(kvk:bezoekLocatie/kvk:buitenlandsAdres)]"/>

            <!-- TODO: Check that verblijfsAdres was not added earlier -->
            <xsl:apply-templates select="kvk:postLocatie/kvk:binnenlandsAdresVanaf"/>

            <xsl:apply-templates select="kvk:communicatieGegevens"/>
            <xsl:apply-templates select="kvk:registratieTijdstip"/>
            <xsl:apply-templates select="kvk:wordtUitgeoefendDoor"/>
        </BG:object>
    </xsl:template>

    <xsl:template match="kvk:vestigingsnummer">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'vestigingsNummer'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:commercieleVestiging/kvk:datumAanvang">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'datumAanvang'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:commercieleVestiging/kvk:datumEinde">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'datumEinde'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:registratieTijdstip">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'tijdstipRegistratie'"/>
            <xsl:with-param name="elementNS" select="'http://www.egem.nl/StUF/StUF0301'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:activiteiten">
        <xsl:apply-templates select="kvk:hoofdSbiActiviteit[1]"/>
        <xsl:apply-templates select="kvk:sbiActiviteit"/>
    </xsl:template>

    <xsl:template match="kvk:hoofdSbiActiviteit[1]">
        <xsl:call-template name="activiteitElement">
            <xsl:with-param name="_indicatieHoofdactiviteit" select="'J'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:sbiActiviteit">
        <xsl:call-template name="activiteitElement"/>
    </xsl:template>

    <xsl:template name="activiteitElement">
        <xsl:param name="_indicatieHoofdactiviteit" select="'N'"/>

        <BG:activiteit>
            <xsl:call-template name="addStUFElementFromContext">
                <xsl:with-param name="elementName" select="'code'"/>
                <!-- De waarde wordt met voorloopnullen aangevuld tot de lengte 15 -->
                <xsl:with-param name="elementValue" select="format-number(kvk:sbiCode, '000000000000000')"/>
            </xsl:call-template>

            <xsl:call-template name="addStUFElementFromContext">
                <xsl:with-param name="elementName" select="'omschrijving'"/>
                <xsl:with-param name="elementValue" select="kvk:omschrijving"/>
            </xsl:call-template>

            <xsl:call-template name="addStUFElementFromContext">
                <xsl:with-param name="elementName" select="'indicatieHoofdactiviteit'"/>
                <xsl:with-param name="elementValue" select="$_indicatieHoofdactiviteit"/>
            </xsl:call-template>
        </BG:activiteit>
    </xsl:template>

    <xsl:template match="kvk:communicatieGegevens">
        <xsl:apply-templates select="kvk:nummer[kvk:soort = 'Telefoon'][1]"/>
        <xsl:apply-templates select="kvk:nummer[kvk:soort = 'Fax'][1]"/>
        <xsl:apply-templates select="kvk:emailAdres[1]"/>
        <xsl:apply-templates select="kvk:domeinNaam[1][string-length(.) &lt;= 200]"/>
    </xsl:template>

    <xsl:template match="kvk:nummer[kvk:soort = 'Telefoon']">
        <xsl:call-template name="telefoonFaxElement">
            <xsl:with-param name="_nummerElementName" select="'sub.telefoonnummer'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:nummer[kvk:soort = 'Fax']">
        <xsl:call-template name="telefoonFaxElement">
            <xsl:with-param name="_nummerElementName" select="'sub.faxnummer'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="telefoonFaxElement">
        <xsl:param name="_nummerElementName"/>

        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="$_nummerElementName"/>
            <xsl:with-param name="elementValue" select="concat(kvk:toegangscode, kvk:nummer)"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:emailAdres">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'sub.emailadres'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:domeinNaam">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'sub.url'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:handeltOnder/kvk:gerelateerde">
        <xsl:call-template name="handeltOnderElements">
            <xsl:with-param name="_volgorde" select="position()"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="handeltOnderElements">
        <xsl:param name="_volgorde"/>

        <xsl:variable name="_handelsnaam">
            <xsl:call-template name="abbreviate">
                <xsl:with-param name="_text" select="kvk:handelsnaam"/>
                <xsl:with-param name="_length" select="200"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'handelsnaam'"/>
            <xsl:with-param name="elementValue" select="$_handelsnaam"/>
        </xsl:call-template>

        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'volgorde'"/>
            <xsl:with-param name="elementValue" select="$_volgorde"/>
        </xsl:call-template>
    </xsl:template>

    <!-- addressing -->

    <xsl:template match="kvk:bezoekLocatie/kvk:binnenlandsAdres[not(kvk:bezoekLocatie/kvk:binnenlandsAdres/kvk:postbusnummer)]">
        <xsl:call-template name="mapToResidenceAddress"/>
    </xsl:template>

    <xsl:template match="kvk:bezoekLocatie/kvk:binnenlandsAdres/kvk:postbusnummer[not(kvk:postLocatie)]">
        <xsl:call-template name="mapToPostalAddress2"/>
    </xsl:template>

    <xsl:template match="kvk:bezoekLocatie/kvk:buitenlandsAdres">
        <xsl:call-template name="mapToForeignAdres"/>
    </xsl:template>

    <xsl:template match="kvk:bezoekLocatie/kvk:binnenlandsAdresVanaf">
        <xsl:call-template name="mapToResidenceAddress"/>
    </xsl:template>

    <xsl:template match="kvk:postLocatie/kvk:binnenlandsAdres[kvk:bezoekLocatie/kvk:binnenlandsAdres/kvk:postbusnummer]">
        <xsl:call-template name="mapToPostalAddress1"/>
    </xsl:template>

    <xsl:template match="kvk:postLocatie/kvk:binnenlandsAdres[not(kvk:bezoekLocatie/kvk:binnenlandsAdres/kvk:postbusnummer)]">
        <xsl:call-template name="mapToPostalAddress2"/>
    </xsl:template>

    <xsl:template match="kvk:postLocatie/kvk:buitenlandsAdres[not(kvk:bezoekLocatie/kvk:buitenlandsAdres)]">
        <xsl:call-template name="mapToForeignAdres"/>
    </xsl:template>

    <xsl:template match="kvk:postLocatie/kvk:binnenlandsAdresVanaf">
        <xsl:call-template name="mapToResidenceAddress"/>
    </xsl:template>

    <!-- addressing mappings -->

    <xsl:template name="mapToResidenceAddress">
        <BG:verblijfsadres>
            <xsl:apply-templates select="kvk:BAGIdentificatie"/>

            <xsl:call-template name="addStUFElementFromContext">
                <xsl:with-param name="elementName" select="'authentiek'"/>
                <xsl:with-param name="elementValue" select="'N'"/>
                <xsl:with-param name="isMetaElement" select="true()"/>
            </xsl:call-template>

            <xsl:apply-templates select="kvk:plaats"/>
            <xsl:apply-templates select="kvk:straatnaam[string-length(.) &lt; 25]"/>
            <xsl:apply-templates select="kvk:postcode" mode="aoa"/>
            <xsl:apply-templates select="kvk:huisnummer"/>
            <xsl:apply-templates select="kvk:huisletter"/>
            <xsl:apply-templates select="kvk:huisnummerToevoeging"/>
        </BG:verblijfsadres>
    </xsl:template>

    <xsl:template name="mapToPostalAddress1">
        <BG:sub.correspondentieAdres>
            <xsl:apply-templates select="kvk:plaats"/>
            <xsl:apply-templates select="kvk:postcode" mode="post"/>

            <xsl:apply-templates select="kvk:BAGIdentificatie"/>

            <xsl:call-template name="addStUFElementFromContext">
                <xsl:with-param name="elementName" select="'authentiek'"/>
                <xsl:with-param name="elementValue" select="'N'"/>
                <xsl:with-param name="isMetaElement" select="true()"/>
            </xsl:call-template>

            <xsl:apply-templates select="kvk:straatnaam[string-length(.) &lt; 25]"/>
            <xsl:apply-templates select="kvk:huisnummer"/>
            <xsl:apply-templates select="kvk:huisletter"/>
            <xsl:apply-templates select="kvk:huisnummerToevoeging"/>
        </BG:sub.correspondentieAdres>
    </xsl:template>

    <xsl:template name="mapToPostalAddress2">
        <BG:sub.correspondentieAdres>
            <xsl:apply-templates select="kvk:plaats"/>
            <xsl:apply-templates select="kvk:postcode" mode="post"/>

            <xsl:apply-templates select="kvk:postbusnummer"/>
        </BG:sub.correspondentieAdres>
    </xsl:template>

    <xsl:template name="mapToForeignAdres">
        <BG:sub.verblijfBuitenland>
            <xsl:apply-templates select="kvk:land"/>
            <xsl:apply-templates select="kvk:straatHuisnummer"/>
            <xsl:apply-templates select="kvk:postcodeWoonplaats"/>
            <xsl:apply-templates select="kvk:regio"/>
        </BG:sub.verblijfBuitenland>
    </xsl:template>

    <xsl:template match="kvk:BAGIdentificatie">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementValue" select="kvk:identificatieAdresseerbaarObject"/>
            <xsl:with-param name="elementName" select="'aoa.identificatie'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:straatnaam">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'gor.openbareRuimteNaam'"/>
        </xsl:call-template>
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'gor.straatnaam'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:huisnummer">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'aoa.huisnummer'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:huisletter">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'aoa.huisletter'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:huisnummerToevoeging">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'aoa.huisnummertoevoeging'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:postcode" mode="aoa">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'aoa.postcode'"/>
            <xsl:with-param name="elementValue" select="concat(kvk:cijfercombinatie, kvk:lettercombinatie)"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:postcode" mode="post">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'postcode'"/>
            <xsl:with-param name="elementValue" select="concat(kvk:cijfercombinatie, kvk:lettercombinatie)"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:plaats">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'wpl.woonplaatsNaam'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:postbusnummer">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'sub.postadresType'"/>
            <xsl:with-param name="elementValue" select="'P'"/>
        </xsl:call-template>
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'sub.postadresNummer'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:straatHuisnummer">
        <xsl:variable name="_value">
            <xsl:call-template name="abbreviate">
                <xsl:with-param name="_text" select="."/>
                <xsl:with-param name="_length" select="35"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'sub.adresBuitenland1'"/>
            <xsl:with-param name="elementValue" select="$_value"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:postcodeWoonplaats">
        <xsl:variable name="_value">
            <xsl:call-template name="abbreviate">
                <xsl:with-param name="_text" select="."/>
                <xsl:with-param name="_length" select="35"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'sub.adresBuitenland2'"/>
            <xsl:with-param name="elementValue" select="$_value"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:regio">
        <xsl:variable name="_value">
            <xsl:call-template name="abbreviate">
                <xsl:with-param name="_text" select="."/>
                <xsl:with-param name="_length" select="35"/>
            </xsl:call-template>
        </xsl:variable>

        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'sub.adresBuitenland3'"/>
            <xsl:with-param name="elementValue" select="$_value"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:land">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'lnd.landnaam'"/>
        </xsl:call-template>
    </xsl:template>

    <!-- wordtUitgeoefendDoor -->

    <xsl:template match="kvk:wordtUitgeoefendDoor/kvk:gerelateerde">
        <BG:oefentActiviteitenUitVoor StUF:entiteittype="VESMAC">
            <BG:gerelateerde StUF:entiteittype="MAC">
                <xsl:apply-templates select="kvk:kvkNummer"/>
                <xsl:apply-templates select="kvk:datumAanvang"/>
                <xsl:apply-templates select="kvk:datumEinde"/>
                <xsl:apply-templates select="kvk:registratieTijdstip"/>

                <xsl:apply-templates select="kvk:handeltOnder/kvk:gerelateerde"/>

                <xsl:apply-templates select="kvk:hoofdSbiActiviteit[1]"/>
                <xsl:apply-templates select="kvk:nevenSbiActiviteit"/>

                <xsl:apply-templates select="kvk:wordtUitgeoefendDoor/kvk:gerelateerde/kvk:heeftAlsEigenaar/kvk:gerelateerde"/>
            </BG:gerelateerde>
        </BG:oefentActiviteitenUitVoor>
    </xsl:template>

    <xsl:template match="kvk:kvkNummer">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'kvkNummer'"/>
        </xsl:call-template>
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'authentiek'"/>
            <xsl:with-param name="elementValue" select="'J'"/>
            <xsl:with-param name="isMetaElement" select="true()"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:wordtUitgeoefendDoor/kvk:gerelateerde/kvk:datumAanvang">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'datumAanvang'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:wordtUitgeoefendDoor/kvk:gerelateerde/kvk:datumEinde">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'datumEinde'"/>
        </xsl:call-template>
    </xsl:template>


    <xsl:template match="kvk:heeftAlsEigenaar/kvk:gerelateerde">
        <BG:heeftAlsEigenaar StUF:entiteittype="MACRPS">
            <BG:gerelateerde>
                <xsl:apply-templates select="kvk:natuurlijkPersoon[../@StUF:entiteitype='PRS']"/>
            </BG:gerelateerde>
        </BG:heeftAlsEigenaar>
    </xsl:template>

    <xsl:template match="kvk:natuurlijkPersoon[../@StUF:entiteitype='PRS']">
        <BG:natuurlijkPersoon StUF:entiteittype="NPS">
            <xsl:apply-templates select="kvk:geslachtsnaam"/>
            <xsl:apply-templates select="kvk:voornamen"/>
            <xsl:apply-templates select="kvk:datumAanvang"/>
            <xsl:apply-templates select="kvk:geboorteland"/>
        </BG:natuurlijkPersoon>
    </xsl:template>

    <xsl:template match="kvk:geslachtsnaam">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'geslachtsnaam'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:voornamen">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'voornamen'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:geboorteland">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'inp.geboorteplaats'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:natuurlijkPersoon/kvk:datumAanvang">
        <xsl:call-template name="addStUFElementFromContext">
            <xsl:with-param name="elementName" select="'geboortedatum'"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="kvk:nevenSbiActiviteit">
        <xsl:call-template name="activiteitElement"/>
    </xsl:template>

</xsl:stylesheet>