<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:StUF="http://www.egem.nl/StUF/StUF0301"
                xmlns:exslt="http://exslt.org/common"
                extension-element-prefixes="exslt">

    <xsl:variable name="DEFAULT_NS" select="'http://www.egem.nl/StUF/sector/bg/0310'"/>

    <xsl:template name="getElementContent">
        <elementContent>
            <elementValue><xsl:value-of select="."/></elementValue>
            <noValue><xsl:value-of select="."/></noValue>
            <exact><xsl:value-of select="."/></exact>
            <indOnvolledigeDatum><xsl:value-of select="."/></indOnvolledigeDatum>
        </elementContent>
    </xsl:template>

    <!-- Place arbitrary StUF element into response message using source node -->
    <xsl:template name="addStUFElement">
        <xsl:param name="elementNS" select="$DEFAULT_NS"/>
        <xsl:param name="elementName"/>
        <xsl:param name="isMetaElement" select="false()"/>
        <xsl:param name="abbreviateToLength" select="0"/>
        <xsl:param name="elementSource"/>

        <!-- -->

        <xsl:if test="$elementSource">

            <xsl:choose>
                <!-- Element value is taken from string -->
                <xsl:when test="exslt:object-type($elementSource)='string'">
                    <xsl:call-template name="addStUFElementAdHoc">
                        <xsl:with-param name="elementNS" select="$elementNS"/>
                        <xsl:with-param name="elementName" select="$elementName"/>
                        <xsl:with-param name="isMetaElement" select="$isMetaElement"/>
                        <xsl:with-param name="noValue"/>
                        <xsl:with-param name="exact"/>
                        <xsl:with-param name="indOnvolledigeDatum"/>
                        <xsl:with-param name="elementValue" select="$elementSource"/>
                        <xsl:with-param name="abbreviateToLength" select="$abbreviateToLength"/>
                    </xsl:call-template>
                </xsl:when>

                <!-- Element value is taken from node -->
                <xsl:when test="exslt:object-type($elementSource)='node-set'">
                    <xsl:variable name="noValue" select="$elementSource/@StUF:noValue"/>
                    <xsl:variable name="exact" select="$elementSource/@StUF:exact"/>
                    <xsl:variable name="indOnvolledigeDatum" select="$elementSource/@StUF:indOnvolledigeDatum"/>
                    <xsl:variable name="elementValue" select="$elementSource"/>

                    <xsl:call-template name="addStUFElementAdHoc">
                        <xsl:with-param name="elementNS" select="$elementNS"/>
                        <xsl:with-param name="elementName" select="$elementName"/>
                        <xsl:with-param name="isMetaElement" select="$isMetaElement"/>
                        <xsl:with-param name="noValue" select="$noValue"/>
                        <xsl:with-param name="exact" select="$exact"/>
                        <xsl:with-param name="indOnvolledigeDatum" select="$indOnvolledigeDatum"/>
                        <xsl:with-param name="elementValue" select="$elementValue"/>
                        <xsl:with-param name="abbreviateToLength" select="$abbreviateToLength"/>
                    </xsl:call-template>
                </xsl:when>

                <!-- Element value is taken from 'resulting tree fragment' -->
                <xsl:when test="exslt:object-type($elementSource)='RTF'">
                    <xsl:variable name="noValue" select="exslt:node-set($elementSource)//noValue"/>
                    <xsl:variable name="exact" select="exslt:node-set($elementSource)//exact"/>
                    <xsl:variable name="indOnvolledigeDatum" select="exslt:node-set($elementSource)//indOnvolledigeDatum"/>
                    <xsl:variable name="elementValue" select="exslt:node-set($elementSource)//elementValue"/>

                    <xsl:call-template name="addStUFElementAdHoc">
                        <xsl:with-param name="elementNS" select="$elementNS"/>
                        <xsl:with-param name="elementName" select="$elementName"/>
                        <xsl:with-param name="isMetaElement" select="$isMetaElement"/>
                        <xsl:with-param name="noValue" select="$noValue"/>
                        <xsl:with-param name="exact" select="$exact"/>
                        <xsl:with-param name="indOnvolledigeDatum" select="$indOnvolledigeDatum"/>
                        <xsl:with-param name="elementValue" select="$elementValue"/>
                        <xsl:with-param name="abbreviateToLength" select="$abbreviateToLength"/>
                    </xsl:call-template>
                </xsl:when>

            </xsl:choose>
        </xsl:if>

    </xsl:template>

    <!-- Place arbitrary StUF element into response message using current tree context-->
    <xsl:template name="addStUFElementFromContext">
        <xsl:param name="elementNS" select="$DEFAULT_NS"/>
        <xsl:param name="elementName"/>
        <xsl:param name="isMetaElement" select="false()"/>
        <xsl:param name="abbreviateToLength" select="0"/>
        <xsl:param name="elementValue" select="."/>
        <xsl:param name="noValue" select="@StUF:noValue"/>
        <xsl:param name="exact" select="@StUF:exact"/>
        <xsl:param name="indOnvolledigeDatum" select="@StUF:indOnvolledigeDatum"/>

        <!-- -->

        <xsl:call-template name="addStUFElementAdHoc">
            <xsl:with-param name="elementNS" select="$elementNS"/>
            <xsl:with-param name="elementName" select="$elementName"/>
            <xsl:with-param name="isMetaElement" select="$isMetaElement"/>
            <xsl:with-param name="noValue" select="$noValue"/>
            <xsl:with-param name="exact" select="$exact"/>
            <xsl:with-param name="indOnvolledigeDatum" select="$indOnvolledigeDatum"/>
            <xsl:with-param name="elementValue" select="$elementValue"/>
            <xsl:with-param name="abbreviateToLength" select="$abbreviateToLength"/>
        </xsl:call-template>

    </xsl:template>

    <!-- Place arbitrary StUF element into response message -->
    <xsl:template name="addStUFElementAdHoc">
        <xsl:param name="elementNS" select="$DEFAULT_NS"/>
        <xsl:param name="elementName"/>
        <xsl:param name="isMetaElement" select="false()"/>
        <xsl:param name="abbreviateToLength" select="0"/>
        <xsl:param name="elementValue"/>
        <xsl:param name="noValue"/>
        <xsl:param name="exact"/>
        <xsl:param name="indOnvolledigeDatum"/>

        <!-- -->

        <xsl:if test="$elementValue">
            <xsl:element name="{$elementName}" namespace="{$elementNS}">
                <xsl:if test="$noValue">
                    <xsl:attribute name="noValue" namespace="http://www.egem.nl/StUF/StUF0301">
                        <xsl:value-of select="$noValue"/>
                    </xsl:attribute>
                </xsl:if>
                <xsl:if test="$exact">
                    <xsl:attribute name="exact" namespace="http://www.egem.nl/StUF/StUF0301">
                        <xsl:value-of select="$exact"/>
                    </xsl:attribute>
                </xsl:if>
                <xsl:if test="$indOnvolledigeDatum">
                    <xsl:attribute name="indOnvolledigeDatum" namespace="http://www.egem.nl/StUF/StUF0301">
                        <xsl:value-of select="$indOnvolledigeDatum"/>
                    </xsl:attribute>
                </xsl:if>
                <xsl:if test="$isMetaElement">
                    <xsl:attribute name="metagegeven" namespace="http://www.egem.nl/StUF/StUF0301">
                        <xsl:value-of select="'true'"/>
                    </xsl:attribute>
                </xsl:if>

                <!-- Support abbreviation inplace -->
                <xsl:choose>
                    <xsl:when test="$abbreviateToLength &gt; 0">
                        <xsl:variable name="abbreviatedValue">
                            <xsl:call-template name="abbreviate">
                                <xsl:with-param name="_text" select="$elementValue"/>
                                <xsl:with-param name="_length" select="$abbreviateToLength"/>
                            </xsl:call-template>
                        </xsl:variable>

                        <xsl:value-of select="$abbreviatedValue"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$elementValue"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:element>
        </xsl:if>
    </xsl:template>

    <!-- Abbreviate text to given lenth -->
    <xsl:template name="abbreviate">

        <xsl:param name="_text"/>
        <xsl:param name="_length"/>

        <xsl:choose>
            <xsl:when test="string-length($_text) &lt;= $_length">
                <xsl:value-of select="$_text"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="$_length &gt; 3 ">
                        <xsl:value-of select="concat(substring($_text, 1, $_length - 3), '...')"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="substring($_text, 1, $_length)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>